@@ -2,7 +2,8 @@ package Dancer::App;
 BEGIN {
   $Dancer::App::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::App::VERSION = '1.3132';
+# ABSTRACT: Base application class for Dancer.
+$Dancer::App::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -248,11 +249,11 @@ __END__
 
 =head1 NAME
 
-Dancer::App
+Dancer::App - Base application class for Dancer.
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
