@@ -2,7 +2,8 @@ package Dancer::Continuation;
 BEGIN {
   $Dancer::Continuation::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Continuation::VERSION = '1.3132';
+# ABSTRACT: Continuation exception (internal exception) for Dancer
+$Dancer::Continuation::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -26,11 +27,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Continuation
+Dancer::Continuation - Continuation exception (internal exception) for Dancer
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
