@@ -2,7 +2,8 @@ package Dancer::Continuation::Halted;
 BEGIN {
   $Dancer::Continuation::Halted::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Continuation::Halted::VERSION = '1.3132';
+# ABSTRACT: Halted internal exception class for Dancer
+$Dancer::Continuation::Halted::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -19,11 +20,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Continuation::Halted
+Dancer::Continuation::Halted - Halted internal exception class for Dancer
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
