@@ -2,17 +2,14 @@ package Dancer::Continuation::Route;
 BEGIN {
   $Dancer::Continuation::Route::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Continuation::Route::VERSION = '1.3132';
+# ABSTRACT: Internal exception class for Route exceptions in Dancer.
+$Dancer::Continuation::Route::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
 
 use base qw(Dancer::Continuation);
 
-# A Dancer::Continuation::Route is a continuation exception, that is caught as
-# route execution level (see Dancer::Route::run). It may store a return_value, that
-# will be recovered from the continuation catcher, and stored as the returning
-# content.
 
 sub return_value { $#_ ? $_[0]->{return_value} = $_[1] : $_[0]->{return_value} }
 
@@ -27,11 +24,20 @@ __END__
 
 =head1 NAME
 
-Dancer::Continuation::Route
+Dancer::Continuation::Route - Internal exception class for Route exceptions in Dancer.
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
+
+=head1 METHODS
+
+=head2 return_value
+
+A Dancer::Continuation::Route is a continuation exception, that is caught as
+route execution level (see Dancer::Route::run). It may store a return_value, that
+will be recovered from the continuation catcher, and stored as the returning
+content.
 
 =head1 AUTHOR
 
