@@ -2,7 +2,8 @@ package Dancer::Continuation::Route::Forwarded;
 BEGIN {
   $Dancer::Continuation::Route::Forwarded::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Continuation::Route::Forwarded::VERSION = '1.3132';
+# ABSTRACT: Internal Dancer exception class
+$Dancer::Continuation::Route::Forwarded::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -19,11 +20,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Continuation::Route::Forwarded
+Dancer::Continuation::Route::Forwarded - Internal Dancer exception class
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
