@@ -2,7 +2,8 @@ package Dancer::Factory::Hook;
 BEGIN {
   $Dancer::Factory::Hook::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Factory::Hook::VERSION = '1.3132';
+# ABSTRACT: Singleton class to create Dancer hooks
+$Dancer::Factory::Hook::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -87,11 +88,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Factory::Hook
+Dancer::Factory::Hook - Singleton class to create Dancer hooks
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
