@@ -2,7 +2,8 @@ package Dancer::Handler;
 BEGIN {
   $Dancer::Handler::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Handler::VERSION = '1.3132';
+# ABSTRACT: Dancer request handler
+$Dancer::Handler::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -221,11 +222,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Handler
+Dancer::Handler - Dancer request handler
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
