@@ -2,7 +2,8 @@ package Dancer::Handler::Standalone;
 BEGIN {
   $Dancer::Handler::Standalone::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Handler::Standalone::VERSION = '1.3132';
+# ABSTRACT: Web server wrapper for Dancer
+$Dancer::Handler::Standalone::VERSION = '1.3134';
 use strict;
 use warnings;
 
@@ -81,11 +82,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Handler::Standalone
+Dancer::Handler::Standalone - Web server wrapper for Dancer
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
