@@ -2,7 +2,8 @@ package Dancer::Renderer;
 BEGIN {
   $Dancer::Renderer::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Renderer::VERSION = '1.3132';
+# ABSTRACT: Rendering class for Dancer
+$Dancer::Renderer::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -328,11 +329,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Renderer
+Dancer::Renderer - Rendering class for Dancer
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
