@@ -2,7 +2,8 @@ package Dancer::Route::Registry;
 BEGIN {
   $Dancer::Route::Registry::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Route::Registry::VERSION = '1.3132';
+# ABSTRACT: Route registry for Dancer
+$Dancer::Route::Registry::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -156,11 +157,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Route::Registry
+Dancer::Route::Registry - Route registry for Dancer
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
