@@ -2,7 +2,8 @@ package Dancer::Serializer::Abstract;
 BEGIN {
   $Dancer::Serializer::Abstract::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Serializer::Abstract::VERSION = '1.3132';
+# ABSTRACT: Base serialiser class for Dancer
+$Dancer::Serializer::Abstract::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -38,11 +39,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Serializer::Abstract
+Dancer::Serializer::Abstract - Base serialiser class for Dancer
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
