@@ -2,7 +2,8 @@ package Dancer::Serializer::Dumper;
 BEGIN {
   $Dancer::Serializer::Dumper::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::Serializer::Dumper::VERSION = '1.3132';
+# ABSTRACT: Data::Dumper serialisation for Dancer
+$Dancer::Serializer::Dumper::VERSION = '1.3134';
 use strict;
 use warnings;
 use Carp;
@@ -49,11 +50,11 @@ __END__
 
 =head1 NAME
 
-Dancer::Serializer::Dumper
+Dancer::Serializer::Dumper - Data::Dumper serialisation for Dancer
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
