@@ -2,7 +2,8 @@ package Dancer::SharedData;
 BEGIN {
   $Dancer::SharedData::AUTHORITY = 'cpan:SUKRIA';
 }
-$Dancer::SharedData::VERSION = '1.3132';
+# ABSTRACT: Shared-data singleton for Dancer
+$Dancer::SharedData::VERSION = '1.3134';
 use strict;
 use warnings;
 use Dancer::Timer;
@@ -74,11 +75,11 @@ __END__
 
 =head1 NAME
 
-Dancer::SharedData
+Dancer::SharedData - Shared-data singleton for Dancer
 
 =head1 VERSION
 
-version 1.3132
+version 1.3134
 
 =head1 AUTHOR
 
